pub trait Config: Config<RuntimeEvent: From<Event<Self>>> + Config<RuntimeEvent: From<Event<Self>>> {
type SetOrigin: EnsureOrigin<Self::RuntimeOrigin>;
type UpdateOrigin: EnsureOrigin<Self::RuntimeOrigin>;
type ValidatorRegistration: ValidatorRegistration<Self::AccountId>;
type MaxValidators: Get<u32>;
type PeriodicSession: ShouldEndSession<BlockNumberFor<Self>>;
type WeightInfo: WeightInfo;
}Expand description
Configuration trait of this pallet.
The main purpose of this trait is to act as an interface between this pallet and the runtime in which it is embedded in. A type, function, or constant in this trait is essentially left to be configured by the runtime that includes this pallet.
Consequently, a runtime that wants to include this pallet must implement this trait. Configuration trait of this pallet.
Required Associated Types
Sourcetype UpdateOrigin: EnsureOrigin<Self::RuntimeOrigin>
type UpdateOrigin: EnsureOrigin<Self::RuntimeOrigin>
Origin allowed to change MaxCollators.
Sourcetype ValidatorRegistration: ValidatorRegistration<Self::AccountId>
type ValidatorRegistration: ValidatorRegistration<Self::AccountId>
Lookup of registered session keys.
Sourcetype MaxValidators: Get<u32>
type MaxValidators: Get<u32>
Maximum number of validators in a received set.
Sourcetype PeriodicSession: ShouldEndSession<BlockNumberFor<Self>>
type PeriodicSession: ShouldEndSession<BlockNumberFor<Self>>
The regular session rotation rule kept next to the forced rotations.
Sourcetype WeightInfo: WeightInfo
type WeightInfo: WeightInfo
Weight information for extrinsics in this pallet.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.